Repository navigation
API
jimsafley edited this page Apr 14, 2013
·
78 revisions
This documentation is a work in progress and subject to change. Assume that resources (records) must be accessible to the consumer, public or via authentication.
yourdomain.com/api[/:version]
Return data about records:
GET /:record-types
- page: integer
- per_page: integer
Return data about the specified record:
GET /:record-types/:id
Return available records (must be registered) and HTTP methods for each record (GET, POST, PUT, DELETE):
GET /record-types
[
{
"name": "collections",
"methods": ["GET", "POST", "PUT", "DELETE"]
},
{
"name": "items",
"methods": ["GET", "POST", "PUT", "DELETE"]
},
{
"name": "files",
"methods": ["GET", "POST", "PUT", "DELETE"]
},
{
"name": "item-types",
"methods": ["GET", "POST", "PUT", "DELETE"]
}
]Return data about collections:
GET /collections
- public: boolean
- featured: boolean
- added_since: string (timestamp)
- modified_since: string (timestamp)
- owner (user): integer
Return data about the specified collection:
GET /collections/:id
[
{
"id": "1",
"public": true,
"featured": false,
"added": "2013-02-13 11:24:34",
"modified": "2013-02-18 11:09:50",
"owner_id": 1
}
]Return data about items:
GET /items
- collection: integer
- item_type: integer
- featured: boolean
- public: boolean
- added_since: string (timestamp)
- modified_since: string (timestamp)
- owner (user): integer
Return data about the specified item:
GET /items/:id
Return data about files:
GET /files
- item: integer
- order: integer
- size_greater_than: integer
- has_derivative_image: boolean
- mime_type: string
- added_since: string (timestamp)
- modified_since: string (timestamp)
Return data about the specified item:
GET /files/:id
GET /item-types
GET /item-types/:id
GET /element-sets
GET /element-sets/:id
GET /elements
GET /elements/:id
GET /users
GET /users/:id
GET /tags
GET /plugins
GET /plugins/:name